@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Interactions {
-    client: Client,
+    pub client: Client,
 }
 
 impl Interactions {
@@ -61,10 +61,7 @@ impl Interactions {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -145,10 +142,7 @@ impl Interactions {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -207,10 +201,7 @@ impl Interactions {
     ) -> Result<crate::types::InteractionLimits> {
         let url = "/user/interaction-limits".to_string();
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
